# Development Scripts

* `scripts/test` - Run the test suite.
* `scripts/lint` - Run the code linting.
* `scripts/publish` - Publish the latest version to PyPI.

Styled after GitHub's ["Scripts to Rule Them All"](https://github.com/github/scripts-to-rule-them-all).
